Identifier Index

[frames] | no frames]

# Identifier Index | [ A B C D E F G H I J K L M N O P Q R S T U V W X Y Z _ ]

## I |
i (in pycocoa.octypes) | isCustom (in Paper) | isNone() (in pycocoa.nstypes)
ID (in Paper) | isDefault (in Printer) | isObjCInstanceOf() (in pycocoa.runtime)
ID (in Printer) | isEnabled (in Item) | isPoster (in Font)
Id_t (in pycocoa.octypes) | isEnabled (in Menu) | isPrintable (in Window)
iget() (in Adict) | isExpanded (in Font) | isPrinter (in Screen)
IMP_t (in pycocoa.octypes) | isExternal (in Screen) | isregistered (in ObjCSubclass)
indentationLevel (in Item) | isExternal (in Window) | isRemote (in Printer)
index() (in Menu) | isFull (in App) | isRunning (in App)
index() (in MenuBar) | isFull (in Window) | isSansSerif (in Font)
index() (in Tuple) | isFullScreen (in App) | isScreen (in Screen)
info (in NSExceptionError) | isFullScreen (in Window) | isSmallCaps (in Font)
inPool (in ObjCInstance) | isHidden (in App) | isUnBold (in Font)
insert() (in List) | isHidden (in Item) | isUnItalic (in Font)
insert() (in Menu) | isHidden (in Menu) | isUp (in App)
insert() (in MenuBar) | isHidden (in Window) | isVertical (in Font)
insert() (in Tuple) | isHighlighted (in Item) | isVisible (in App)
inst (in ObjCBoundMethod) | isHighlighted (in Menu) | isVisible (in Menu)
inst2strepr() (in pycocoa.utils) | isImmutable() (in pycocoa.runtime) | isVisible (in MenuBar)
int2NS() (in pycocoa.pytypes) | isinstanceOf() (in pycocoa.utils) | isVisible (in Window)
internals (in pycocoa) | isItalic (in Font) | isZoomed (in App)
is_enabled() (in pycocoa.faults) | isKey (in Window) | isZoomed (in Window)
isActive (in App) | isLazy (in pycocoa) | Item (in pycocoa.menus)
isAlias() (in pycocoa.nstypes) | isLazy (in pycocoa.lazily) | item (in pycocoa.menus)
isAlternate (in Item) | isLink() (in pycocoa.nstypes) | item() (in Menu)
isBold (in Font) | islistuple() (in pycocoa.utils) | items() (in FrozenDict)
isBuiltIn (in Screen) | isMain (in Screen) | items() (in Menu)
isBuiltIn (in Window) | isMain (in Window) | ItemSeparator (in pycocoa.menus)
isClass() (in pycocoa.runtime) | isMetaClass() (in pycocoa.runtime) | iterable2NS() (in pycocoa.pytypes)
isColor (in Printer) | isMonoSpace (in Font) | iterbytes() (in pycocoa.internals)
isCompressed (in Font) | isMutable() (in pycocoa.runtime) | Ivar_t (in pycocoa.octypes)
isCondensed (in Font) | isNarrow (in Font) |